Threshold-Based Evaluation
==========================
.. automodule:: pykeen.evaluation.sklearn
.. autoclass:: pykeen.evaluation.SklearnMetricResults
.. autoclass:: pykeen.evaluation.SklearnEvaluator
